R/dump_fontdb.R
dump_fontdb.Rd
For debugging purposes, extract all font faces on the font database which 'string2path' uses internally.
dump_fontdb()
A tibble() containing these columns:
tibble()
The index of the font face within the source.
The font family of the face.
The numeric weight of the face (e.g. 400 for normal, 700 for bold).
The style of the face.